from setuptools import setup

setup(
    name="py-kr",
    description="파이썬을 한국어로!",
    version="1.2.0",
    author="Nergis",
    author_email="dev-nergis@textcord.xyz",
    license="MIT",
    requires=["pydantic"],
    py_modules=["기능", "랜덤", "함수"],
)
